| Title: | Easily Install and Load Survey Analysis Packages |
|---|---|
| Description: | Makes it easy to install and load a collection of packages for survey analysis that build upon the foundational 'survey' package of Lumley (2004) <doi:10.18637/jss.v009.i08>. Schneider (2025) <https://isi-iass.org/home/wp-content/uploads/Survey_Statistician_2025_January_N91_06.pdf> describes the three core packages in this collection. |
| Authors: | Ben Schneider [aut, cre, cph], Hadley Wickham [ctb] (Vendored code from the tidyverse package is used in surveyverse) |
| Maintainer: | Ben Schneider <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.1 |
| Built: | 2026-07-22 09:35:12 UTC |
| Source: | https://github.com/bschneidr/surveyverse |
Lists all conflicts between surveyverse packages and other packages that you have loaded. Conflicts are only reported for functions; identical implementations in different packages are silently ignored.
surveyverse_conflicts(only = NULL)surveyverse_conflicts(only = NULL)
only |
Optionally restrict to conflicts with a specific character vector of package names. |
Use the conflicted package to turn all conflicts into errors.
An object of class surveyverse_conflicts, listing specific conflicts
between surveyverse packages and other packages.
surveyverse_conflicts()surveyverse_conflicts()
List all packages in the surveyverse
surveyverse_packages(include_self = TRUE, core_only = TRUE)surveyverse_packages(include_self = TRUE, core_only = TRUE)
include_self |
Include surveyverse in the list? |
core_only |
Whether to include only the core packages |
A character vector of package names
surveyverse_packages()surveyverse_packages()