Package {surveyverse}


Title: Easily Install and Load Survey Analysis Packages
Version: 0.1.1
Description: Makes it easy to install and load a collection of packages for survey analysis that build upon the foundational 'survey' package of Lumley (2004) <doi:10.18637/jss.v009.i08>. Schneider (2025) https://isi-iass.org/home/wp-content/uploads/Survey_Statistician_2025_January_N91_06.pdf describes the three core packages in this collection.
License: GPL (≥ 3)
Encoding: UTF-8
RoxygenNote: 8.0.0
Imports: cli, rlang, survey, srvyr, svrep, svyVGAM, svylme, stats
Suggests: spelling
Language: en-US
URL: https://github.com/bschneidr/surveyverse
BugReports: https://github.com/bschneidr/surveyverse/issues
NeedsCompilation: no
Packaged: 2026-07-12 14:50:33 UTC; benja
Author: Ben Schneider [aut, cre, cph], Hadley Wickham [ctb] (Vendored code from the tidyverse package is used in surveyverse)
Maintainer: Ben Schneider <benjamin.julius.schneider@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-21 10:50:02 UTC

surveyverse: Easily Install and Load Survey Analysis Packages

Description

Makes it easy to install and load a collection of packages for survey analysis that build upon the foundational 'survey' package of Lumley (2004) doi:10.18637/jss.v009.i08. Schneider (2025) https://isi-iass.org/home/wp-content/uploads/Survey_Statistician_2025_January_N91_06.pdf describes the three core packages in this collection.

Author(s)

Maintainer: Ben Schneider benjamin.julius.schneider@gmail.com [copyright holder]

Authors:

Other contributors:

See Also

Useful links:


Conflicts between the surveyverse and other packages

Description

Lists all conflicts between surveyverse packages and other packages that you have loaded. Conflicts are only reported for functions; identical implementations in different packages are silently ignored.

Usage

surveyverse_conflicts(only = NULL)

Arguments

only

Optionally restrict to conflicts with a specific character vector of package names.

Details

Use the conflicted package to turn all conflicts into errors.

Value

An object of class surveyverse_conflicts, listing specific conflicts between surveyverse packages and other packages.

Examples

surveyverse_conflicts()

List all packages in the surveyverse

Description

List all packages in the surveyverse

Usage

surveyverse_packages(include_self = TRUE, core_only = TRUE)

Arguments

include_self

Include surveyverse in the list?

core_only

Whether to include only the core packages

Value

A character vector of package names

Examples

surveyverse_packages()

mirror server hosted at Truenetwork, Russian Federation.